==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/mail/inc/function.import.php <==
<?
function inport2db($id,$address,$global)
{
  global $config,$user,$groupsessid,$share,$lang;
  if(!is_array($address)) return;

  include_once("inc/function.calendar.php");
  $sessid= logtocalendar($user,$config['EMAIL'],$config['PASS']);
  $calsettings=loadcalendarsettings($cal_default,$cv,$sessid);

  reset($address);
  while (list (, $val) = each ($address))
  {

        unset($datain,$addressbirth,$addressanniversary);

        if($val['BIRTH'])
        {
          list($addressbirth1,$addressbirth2,$addressbirth3)=explode(".",$addressbirth);
          if($addressbirth1 && $addressbirth2 && $addressbirth3) $addressbirth=calendardatetostr($addressbirth3,$addressbirth2,$addressbirth1); else $addressbirth="";
        }
        if($val['ANNIVERSARY']){
          list($addressanniversary1,$addressanniversary2,$addressanniversary3)=explode(".",$addressanniversary);
          if($addressanniversary1 && $addressanniversary2 && $addressanniversary3) $addressanniversary=calendardatetostr($addressanniversary3,$addressanniversary2,$addressanniversary1); else $addressanniversary="";
        }

        if(!$val['NAME'])
        {
          if($val['NAME1'] || $val['NAME3'])
            $val['NAME']=trim($val['NAME1']." ".$val['NAME3']);
          elseif($val['NICK'])
            $val['NAME']=$val['NICK'];
          else
            $val['NAME']=$lang["MSG_NONAME"];
        }


        $datain[ITMFIRSTNAME]=$val['NAME1'];
        $datain[ITMMIDDLENAME]=$val['NAME2'];

        $datain[ITMSHARETYPE]=$share==="U"?'U':'P';

        $datain[ITMTITLE]=$val['TITLE'];
        $datain[ITMSURNAME]=$val['NAME3'];
        $datain[ITMJOBTITLE]=$val['JOB'];
        $datain[ITMCOMPANY]=$val['ORGANIZATION'];
        $datain[ITMCLASSIFYAS]=$val['NAME'];
        $datain[ITMDESCRIPTION]=$val['NOTE'];
        $datain[ITMOFFICELOCATION]=$val['OFFICE'];
        $datain[ITMGENDER]=$val['SEX'];
        $datain[ITMPROFESSION]=$val['PROFESSION'];
        $datain[ITMDEPARTMENT]=$val['SEX'];
        $datain[ITMNICKNAME]=$val['NICK'];
        $datain[ITMBDATE]=$addressbirth;
        $datain[ITMSPOUSE]=$val['SPOUSE'];
        $datain[ITMANNIVERSARY]=$addressanniversary;
        $datain[ITMINTERNETFREEBUSY]=$val['CALENDARURL'];
        $datain[ITMASSISTANTNAME]=$val['ASSISTANT'];
        $datain[ITMMANAGERNAME]=$val['MANAGER'];
        $datain[ITMCATEGORY]=$val['CATEGORY'];

        $cid=calendarfunctioncall("AddContactInfo",$groupsessid,createcalendarparameters($datain),$addressid);

        if($cid)
        {
            //calendarfunctioncall("SetContactCertificate",$groupsessid,$cid,$addresscertificate);

            calendarfunctioncall("DeleteContactLocations",$groupsessid,$cid);
            unset($datain);
            $datain[LCTTYPE]='B';
            $datain[LCTWEBPAGE]=$val['URL'];
            $datain[LCTEMAIL1]=$val['EMAIL'];
            $datain[LCTEMAIL2]=$val['EMAIL2'];
            $datain[LCTEMAIL3]=$val['EMAIL3'];

            $datain[LCTSTREET]=$val['STREETB'];
            $datain[LCTCITY]=$val['CITYB'];
            $datain[LCTSTATE] =$val['STATEB'];
            $datain[LCTCOUNTRY]=$val['COUNTRYB'];
            $datain[LCTZIP] =$val['ZIPB'];

            $LcB=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE1TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE1'];
              $datain1[PHNDESCRIPTION]=$val['PHONE1T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE2']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE2TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE2'];
              $datain1[PHNDESCRIPTION]=$val['PHONE2T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE3']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE3TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE3'];
              $datain1[PHNDESCRIPTION]=$val['PHONE3T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE4']) {
              unset($datain4);
              $datain1[PHNTYPE]=$val['PHONE4TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE4'];
              $datain1[PHNDESCRIPTION]=$val['PHONE4T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }

            $datain[LCTTYPE]='H';
            $datain[LCTSTREET]=$val['STREETH'];
            $datain[LCTCITY]=$val['CITYH'];
            $datain[LCTSTATE] =$val['STATEH'];
            $datain[LCTCOUNTRY]=$val['COUNTRYH'];
            $datain[LCTZIP] =$val['ZIPH'];

            $LcH=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain1));
            if($val['PHONE2']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain2));
            if($val['PHONE3']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain3));
            if($val['PHONE4']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain4));

            $datain[LCTTYPE]='O';
            $datain[LCTSTREET]=$val['STREET'];
            $datain[LCTCITY]=$val['CITY'];
            $datain[LCTSTATE] =$val['STATE'];
            $datain[LCTCOUNTRY]=$val['COUNTRY'];
            $datain[LCTZIP] =$val['ZIP'];

            $LcO=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain1));
            if($val['PHONE2']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain2));
            if($val['PHONE3']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain3));
            if($val['PHONE4']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain4));
          }
  }
}


function inport2txt($id,$address,$global)
{
  global $lang;
  if(!is_array($address)) return;

        $addresses = getaddresses($id, !$global,2);
        $index = getfreeaddressindex($addresses);

        reset($address);
        while (list ($key, $val) = each ($address))
        {
        //   if(!$val[NAME] && !$val[NAME1] && !$val[NAME2] && !$val[NAME3] && !$val[NICK]) continue;

           if(!$val['NAME'])
           {
             if($val['NAME1'] || $val['NAME3'])
               $val['NAME']=trim($val['NAME1']." ".$val['NAME3']);
             elseif($val['NICK'])
               $val['NAME']=$val['NICK'];
             else
               $val['NAME']=$lang["MSG_NONAME"];
           }

           $val['ID']=$index;
           $val['NAME']=$val['NAME'];
           $addresses[]=$val;
           $index++;
        }

        saveaddresses($id, $addresses, !$global);
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/mail/inc/function.import.php <==
<?
function inport2db($id,$address,$global)
{
  global $config,$user,$groupsessid,$share,$lang;
  if(!is_array($address)) return;

  include_once("inc/function.calendar.php");
  $sessid= logtocalendar($user,$config['EMAIL'],$config['PASS']);
  $calsettings=loadcalendarsettings($cal_default,$cv,$sessid);

  reset($address);
  while (list (, $val) = each ($address))
  {
		unset($datain,$addressbirth,$addressanniversary);

        if($val['BIRTH'])
        {
          list($addressbirth1,$addressbirth2,$addressbirth3)=explode(".",$addressbirth);
          if($addressbirth1 && $addressbirth2 && $addressbirth3) $addressbirth=calendardatetostr($addressbirth3,$addressbirth2,$addressbirth1); else $addressbirth="";
        }
        if($val['ANNIVERSARY']){
          list($addressanniversary1,$addressanniversary2,$addressanniversary3)=explode(".",$addressanniversary);
          if($addressanniversary1 && $addressanniversary2 && $addressanniversary3) $addressanniversary=calendardatetostr($addressanniversary3,$addressanniversary2,$addressanniversary1); else $addressanniversary="";
        }

        if(!$val['NAME'])
        {
          if($val['NAME1'] || $val['NAME3'])
            $val['NAME']=trim($val['NAME1']." ".$val['NAME3']);
          elseif($val['NICK'])
            $val['NAME']=$val['NICK'];
          else
            $val['NAME']=$lang["MSG_NONAME"];
        }


        $datain[ITMCLASS] = 'C';
        
		$datain[ITMFIRSTNAME]=$val['NAME1'];
        $datain[ITMMIDDLENAME]=$val['NAME2'];

        $datain[ITMSHARETYPE]=$share==="U"?'U':'P';

        $datain[ITMTITLE]=$val['TITLE'];
        $datain[ITMSURNAME]=$val['NAME3'];
        $datain[ITMJOBTITLE]=$val['JOB'];
        $datain[ITMCOMPANY]=$val['ORGANIZATION'];
        $datain[ITMCLASSIFYAS]=$val['NAME'];
        $datain[ITMDESCRIPTION]=$val['NOTE'];
        $datain[ITMOFFICELOCATION]=$val['OFFICE'];
        $datain[ITMGENDER]=$val['SEX'];
        $datain[ITMPROFESSION]=$val['PROFESSION'];
        $datain[ITMDEPARTMENT]=$val['SEX'];
        $datain[ITMNICKNAME]=$val['NICK'];
        $datain[ITMBDATE]=$addressbirth;
        $datain[ITMSPOUSE]=$val['SPOUSE'];
        $datain[ITMANNIVERSARY]=$addressanniversary;
        $datain[ITMINTERNETFREEBUSY]=$val['CALENDARURL'];
        $datain[ITMASSISTANTNAME]=$val['ASSISTANT'];
        $datain[ITMMANAGERNAME]=$val['MANAGER'];
        $datain[ITMCATEGORY]=$val['CATEGORY'];

        $cid=calendarfunctioncall("AddContactInfo",$groupsessid,createcalendarparameters($datain),$addressid);

        if($cid)
        {
            calendarfunctioncall("SetContactCertificate",$groupsessid,$cid,$addresscertificate);

            calendarfunctioncall("DeleteContactLocations",$groupsessid,$cid);
            unset($datain);
            $datain[LCTTYPE]='B';
            $datain[LCTWEBPAGE]=$val['URL'];
            $datain[LCTEMAIL1]=$val['EMAIL'];
            $datain[LCTEMAIL2]=$val['EMAIL2'];
            $datain[LCTEMAIL3]=$val['EMAIL3'];

            $datain[LCTSTREET]=$val['STREETB'];
            $datain[LCTCITY]=$val['CITYB'];
            $datain[LCTSTATE] =$val['STATEB'];
            $datain[LCTCOUNTRY]=$val['COUNTRYB'];
            $datain[LCTZIP] =$val['ZIPB'];

            $LcB=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE1TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE1'];
              $datain1[PHNDESCRIPTION]=$val['PHONE1T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE2']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE2TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE2'];
              $datain1[PHNDESCRIPTION]=$val['PHONE2T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE3']) {
              unset($datain1);
              $datain1[PHNTYPE]=$val['PHONE3TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE3'];
              $datain1[PHNDESCRIPTION]=$val['PHONE3T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }
            if($val['PHONE4']) {
              unset($datain4);
              $datain1[PHNTYPE]=$val['PHONE4TYPE'];
              $datain1[PHNNUMBER]=$val['PHONE4'];
              $datain1[PHNDESCRIPTION]=$val['PHONE4T'];
              calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcB,createcalendarparameters($datain1));
            }

            $datain[LCTTYPE]='H';
            $datain[LCTSTREET]=$val['STREETH'];
            $datain[LCTCITY]=$val['CITYH'];
            $datain[LCTSTATE] =$val['STATEH'];
            $datain[LCTCOUNTRY]=$val['COUNTRYH'];
            $datain[LCTZIP] =$val['ZIPH'];

            $LcH=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain1));
            if($val['PHONE2']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain2));
            if($val['PHONE3']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain3));
            if($val['PHONE4']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcH,createcalendarparameters($datain4));

            $datain[LCTTYPE]='O';
            $datain[LCTSTREET]=$val['STREET'];
            $datain[LCTCITY]=$val['CITY'];
            $datain[LCTSTATE] =$val['STATE'];
            $datain[LCTCOUNTRY]=$val['COUNTRY'];
            $datain[LCTZIP] =$val['ZIP'];

            $LcO=calendarfunctioncall("AddContactLocation",$groupsessid,$cid,createcalendarparameters($datain));

            if($val['PHONE1']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain1));
            if($val['PHONE2']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain2));
            if($val['PHONE3']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain3));
            if($val['PHONE4']) calendarfunctioncall("AddContactLocationPhone",$groupsessid,$LcO,createcalendarparameters($datain4));

	    // Finalize
            calendarfunctioncall("AddContactInfo",$groupsessid,'',$cid);
          }
  }
}


function inport2txt($id,$address,$global)
{
  global $lang;
  if(!is_array($address)) return;

        $addresses = getaddresses($id, !$global,2);
        $index = getfreeaddressindex($addresses);

        reset($address);
        while (list ($key, $val) = each ($address))
        {
        //   if(!$val[NAME] && !$val[NAME1] && !$val[NAME2] && !$val[NAME3] && !$val[NICK]) continue;

           if(!$val['NAME'])
           {
             if($val['NAME1'] || $val['NAME3'])
               $val['NAME']=trim($val['NAME1']." ".$val['NAME3']);
             elseif($val['NICK'])
               $val['NAME']=$val['NICK'];
             else
               $val['NAME']=$lang["MSG_NONAME"];
           }

           $val['ID']=$index;
           $val['NAME']=$val['NAME'];
           $addresses[]=$val;
           $index++;
        }

        saveaddresses($id, $addresses, !$global);
}
?>
